==> haskell-hsyaml-aeson-0.2.0.1-255-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hsyaml-aeson.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 HsYAML-aeson
version:              0.2.0.1
visibility:           public
id:                   HsYAML-aeson-0.2.0.1-JgK8GHW8aDd4U8MV31g2gw
key:                  HsYAML-aeson-0.2.0.1-JgK8GHW8aDd4U8MV31g2gw
license:              GPL-2.0-or-later
copyright:            2018-2019 Herbert Valerio Riedel
maintainer:           hvr@gnu.org, Andreas Abel
author:               Herbert Valerio Riedel
synopsis:             JSON to YAML Adapter
description:
    The [YAML 1.2](https://yaml.org/spec/1.2/spec.html) format provides
    a much richer data-model and feature-set
    than the [JavaScript Object Notation (JSON)](https://tools.ietf.org/html/rfc7159) format.
    However, sometimes it'\''s desirable to ignore the extra capabilities
    and treat YAML as if it was merely a more convenient markup format
    for humans to write JSON data. To this end this module provides a
    compatibility layer atop [HsYAML](https://hackage.haskell.org/package/HsYAML)
    which allows decoding YAML documents in the more limited JSON data-model while also providing
    convenience by reusing [aeson](https://hackage.haskell.org/package/aeson)'\''s
    '\''FromJSON'\'' instances for decoding the YAML data into native Haskell data types.

category:             Text, Codec, Web, JSON, YAML
abi:                  de412b6f4584166b10d8e01c1bbd3b2a
exposed:              True
exposed-modules:      Data.YAML.Aeson
import-dirs:          /usr/lib/ghc-9.4.8/site-local/HsYAML-aeson-0.2.0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/HsYAML-aeson-0.2.0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/HsYAML-aeson-0.2.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hsyaml-aeson
hs-libraries:         HSHsYAML-aeson-0.2.0.1-JgK8GHW8aDd4U8MV31g2gw
depends:
    HsYAML-0.2.1.4-KcmPpVU89E4E8jiIDa5XaU
    aeson-2.1.2.1-F9MXb1A8ug6GkYytoGh4jA base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7 mtl-2.2.2
    scientific-0.3.7.0-IuEDgnpy5lN4JI5naZeXd4 text-2.0.2
    unordered-containers-0.2.20-Kb1zmdIZFsX5Z4trT8w0xB
    vector-0.13.2.0-3KdUWUHYfVjDmpelwHDbn6

haddock-interfaces:
    /usr/share/doc/haskell-hsyaml-aeson/html/HsYAML-aeson.haddock

haddock-html:         /usr/share/doc/haskell-hsyaml-aeson/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hsyaml-aeson-0.2.0.1-256-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hsyaml-aeson.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 HsYAML-aeson
version:              0.2.0.1
visibility:           public
id:                   HsYAML-aeson-0.2.0.1-3CMse3QcXLdfUnBcaH8H6
key:                  HsYAML-aeson-0.2.0.1-3CMse3QcXLdfUnBcaH8H6
license:              GPL-2.0-or-later
copyright:            2018-2019 Herbert Valerio Riedel
maintainer:           hvr@gnu.org, Andreas Abel
author:               Herbert Valerio Riedel
synopsis:             JSON to YAML Adapter
description:
    The [YAML 1.2](https://yaml.org/spec/1.2/spec.html) format provides
    a much richer data-model and feature-set
    than the [JavaScript Object Notation (JSON)](https://tools.ietf.org/html/rfc7159) format.
    However, sometimes it'\''s desirable to ignore the extra capabilities
    and treat YAML as if it was merely a more convenient markup format
    for humans to write JSON data. To this end this module provides a
    compatibility layer atop [HsYAML](https://hackage.haskell.org/package/HsYAML)
    which allows decoding YAML documents in the more limited JSON data-model while also providing
    convenience by reusing [aeson](https://hackage.haskell.org/package/aeson)'\''s
    '\''FromJSON'\'' instances for decoding the YAML data into native Haskell data types.

category:             Text, Codec, Web, JSON, YAML
abi:                  9fc237b24f1201531a3d42b4c0ae96ab
exposed:              True
exposed-modules:      Data.YAML.Aeson
import-dirs:          /usr/lib/ghc-9.4.8/site-local/HsYAML-aeson-0.2.0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/HsYAML-aeson-0.2.0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/HsYAML-aeson-0.2.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hsyaml-aeson
hs-libraries:         HSHsYAML-aeson-0.2.0.1-3CMse3QcXLdfUnBcaH8H6
depends:
    HsYAML-0.2.1.4-CH4pJWTLtC0HUkNslG781g
    aeson-2.1.2.1-HPwo2VO3hzcFr4fiGB5Oro base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7 mtl-2.2.2
    scientific-0.3.7.0-58CM7xG7oFa5aLaqCWIm5T text-2.0.2
    unordered-containers-0.2.20-FFF0GulGLFtAHq6N1Lkm0s
    vector-0.13.2.0-ZKpjTfyjPa7BNElf7Ue7Z

haddock-interfaces:
    /usr/share/doc/haskell-hsyaml-aeson/html/HsYAML-aeson.haddock

haddock-html:         /usr/share/doc/haskell-hsyaml-aeson/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
